@@ -1,9 +1,11 @@
 #include "mainwindow.h"
 #ifdef Q_WS_MAEMO_5
+
 #include <QtMaemo5>
 #include <QtGui/QX11Info>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
+
 void MainWindow::grabZoomKeys(bool grab)
      {
          if (!winId()) {
@@ -30,6 +32,50 @@ void MainWindow::grabZoomKeys(bool grab)
                  reinterpret_cast<unsigned char *>(&val),
                  1);
      }
+
+
+void MainWindow::headphoneEvent(QString what,QString how)
+{
+    if (what != "ButtonPressed" || how != "connection")
+        return;
+    bool present = QDBusInterface ("org.freedesktop.Hal",
+                    "/org/freedesktop/Hal/devices/platform_headphone",
+                    "org.freedesktop.Hal.Device",
+                    QDBusConnection::systemBus()).call ("GetProperty", "button.state.value").arguments().at(0).toBool();
+// head disconnect
+    if (!present)
+    {
+        switch(on_head_dis){
+        case 1:
+            moo->pause();
+            break;
+        case 2:
+            device->setMuted(true);
+            break;
+        case 3:
+            qApp->exit();
+            break;
+        }
+
+    }
+
+// head connect
+
+    if (present)
+    {
+        switch(on_head_con){
+        case 1:
+            moo->play();
+            break;
+        case 2:
+            device->setMuted(false);
+            break;
+        }
+
+    }
+
+}
+
 #endif
 
 MainWindow::MainWindow(QWidget *parent)
@@ -195,18 +241,26 @@ if (row!=-1)
 
 #ifdef Q_WS_MAEMO_5
 grabZoomKeys(true);
-#endif
-
-#ifdef Q_WS_MAEMO_5
 QAbstractKineticScroller *scroller =ui.textEdit->property("kineticScroller").value<QAbstractKineticScroller *>();
 scroller->setEnabled(true);
 QAbstractKineticScroller *scroller2 =ui.textEdit_2->property("kineticScroller").value<QAbstractKineticScroller *>();
 scroller2->setEnabled(true);
+
+
+    QDBusConnection::systemBus().connect(QString(), "/org/freedesktop/Hal/devices/platform_headphone", "org.freedesktop.Hal.Device", "Condition", this, SLOT(headphoneEvent(QString,QString)));
+
 #endif
 
  QList<QWidget *> widgets = this->ui.centralwidget->findChildren<QWidget *>();
 for (int i=0;i<widgets.count();i++)
      widgets.at(i)->installEventFilter(this);
+
+
+if (on_start==1){
+    next();
+    // should save previous song name and start it
+    // not the first
+}
 }
 
 void MainWindow::reload(){
@@ -300,7 +354,8 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *event)
         return true;
         break;
 
-        default: return QObject::eventFilter(obj, event); break;
+        default:
+            return QObject::eventFilter(obj, event); break;
 
 
 
@@ -405,22 +460,21 @@ void MainWindow::load(){
 
 
             QStringList tyu=QString(file.readAll()).split("\n");
+            while (tyu.count()<10)tyu.append("");
+
             rotate=tyu.at(0).toLong();
             QFont h(tyu.at(1));
 
             h.setPointSize(tyu.at(2).toLong());
             ui.listWidget->setFont(h);
             namefilter=QString(tyu.at(3)).split(" ");
-            if (tyu.count()>4){
+
 scrobler=new last(tyu.at(4),tyu.at(5));
-
-}
-            else{
-                scrobler=new last("","");
-
-            }
-            if (tyu.count()>6)iload=QString(tyu.at(6)).toLong();else iload=0;
-
+scrobler=new last("","");
+iload=QString(tyu.at(6)).toLong();
+on_head_dis=QString(tyu.at(7)).toLong();
+on_head_con=QString(tyu.at(8)).toLong();
+on_start=QString(tyu.at(9)).toLong();
 
 file.close();
 #ifdef Q_WS_MAEMO_5
@@ -960,7 +1014,7 @@ void MainWindow::pl_fn_add_dir(){
 
 
     QString d;
-    QString f=QFileDialog::getExistingDirectory(this,"Tplayer",QDesktopServices::storageLocation(QDesktopServices::MusicLocation),QFileDialog::ReadOnly);
+    QString f=QFileDialog::getExistingDirectory(this,"Tplayer","/home/user/MyDocs/.sounds",QFileDialog::ReadOnly);
    QApplication::processEvents();
 
     if (!f.isEmpty())
