@@ -10,6 +10,9 @@
 #include "lmaster.h"
 #include <QtSql>
 #include <QEvent>
+#ifdef Q_WS_MAEMO_5
+#include <QtDBus>
+#endif
 
 class MainWindow : public QMainWindow, private Ui::MainWindow
 {
@@ -45,7 +48,11 @@ public:
     Phonon::Effect      *eqEffect;
     QList<QSlider*> sliders;
     Phonon::Path audioPath;
+    int on_head_con;
+    int on_head_dis;
+    int on_start;
 public slots:
+
     void toggleEqualizer(bool);
     void sliderChanged (int);
     void resetAll ();
@@ -76,8 +83,8 @@ public slots:
     void reload();
     #ifdef Q_WS_MAEMO_5
     void grabZoomKeys(bool grab);
-
-#endif
+    void headphoneEvent (QString,QString);
+    #endif
     void dart();
     void dart2();
     void replyFinished2(QNetworkReply*);
